@@ -499,6 +499,36 @@ tosca-parser/master/toscaparser/tests/data/custom_types/wordpress.yaml
         self.assertTrue(custom_defs.get("mycompany.tosca.nodes."
                                         "WebApplication.WordPress"))
 
+    @mock.patch.object(urllib.request, 'urlopen')
+    def test_imports_with_local_defs(self, mock_urlopen):
+        """Compare custom types on local and remote."""
+
+        ctypes = {
+            "remote": "https://example.com/custom_types/wordpress.yaml",
+            "local": "../data/wordpress.yaml"}
+        mock_path = "https://example.com/custom_types/wordpress.yaml"
+
+        mockclass = MockTestClass()
+        mockclass.comp_urldict = {
+            mock_path: os.path.join(os.path.dirname(os.path.abspath(__file__)),
+                                    "data/custom_types/wordpress.yaml")}
+        mock_urlopen.side_effect = mockclass.mock_urlopen_method
+
+        tpl_snippet = '''
+        imports:
+        - {}
+        '''.format(ctypes["remote"])
+        local_defs = {ctypes["remote"]: ctypes["local"]}
+
+        path = os.path.join(
+            os.path.dirname(os.path.abspath(__file__)),
+            "data/tosca_elk.yaml")
+        imports = (toscaparser.utils.yamlparser.
+                   simple_parse(tpl_snippet)['imports'])
+        ld1 = ImportsLoader(imports, path, "node_types")
+        ld2 = ImportsLoader(imports, path, "node_types", local_defs)
+        self.assertEqual(ld1.get_custom_defs(), ld2.get_custom_defs())
+
     def test_imports_file_with_suffix_yml(self):
         tpl_snippet = '''
         imports:
